package ch.iet_gibb.heatcalculatorfx.application;

import ch.iet_gibb.heatcalculatorfx.model.CuboidHeatstorage;
import ch.iet_gibb.heatcalculatorfx.model.CylindricalHeatstorage;
import ch.iet_gibb.heatcalculatorfx.model.GeneralHeatstorage;
import ch.iet_gibb.heatcalculatorfx.model.Heatstorage;
import ch.iet_gibb.heatcalculatorfx.view.HeatstorageView_1;
import ch.iet_gibb.heatcalculatorfx.view.HeatstorageView_2;
import javafx.application.Application;
import javafx.stage.Stage;

import java.util.ArrayList;
import java.util.List;

/**
 * Main application class for the Heat Calculator FX application.
 * Extends the JavaFX Application class to manage the lifecycle of the application.
 */
public class HeatCalculatorFX extends Application {

    /**
     * Entry point for the JavaFX application.
     * Initializes the models, controller, and view, and starts the application.
     *
     * @param stage The primary stage for the application.
     * @throws Exception If an error occurs during initialization.
     */
    @Override
    public void start(Stage stage) throws Exception {
        // Create the list of heat storage models
        List<GeneralHeatstorage> storages = createModels();

        // Initialize the controller with the models
        HeatCalculatorController controller = new HeatCalculatorController(storages);

        // Create the view and associate it with the controller
        HeatstorageView_1 view = new HeatstorageView_1(stage, controller);
        controller.setView(view);

        // Start the view
        controller.startView();
    }

    /**
     * Main method to launch the JavaFX application.
     *
     * @param args Command-line arguments.
     */
    public static void main(String[] args) {
        launch(args);
    }

    /**
     * Creates and initializes a list of heat storage models.
     *
     * @return A list of GeneralHeatstorage objects representing different heat storages.
     */
    protected List<GeneralHeatstorage> createModels() {
        ArrayList<GeneralHeatstorage> storages = new ArrayList<>();

        // Create and add a basic heat storage model
        Heatstorage heatstorage_1 = new Heatstorage("Speicher 1", 23.3f, 45f, 22f);
        storages.add(heatstorage_1);

        // Create and add a cylindrical heat storage model
        CylindricalHeatstorage heatstorage_2 = new CylindricalHeatstorage("Speicher 2", 50f, 12f, 70f, 43f);
        storages.add(heatstorage_2);

        // Create and add a cuboid heat storage model
        CuboidHeatstorage heatstorage_3 = new CuboidHeatstorage("Speicher 3", 80f, 20f, 40f, 60f, 55.3f);
        storages.add(heatstorage_3);

        return storages;
    }
}