package ch.iet_gibb.heatcalculatorfx.application;

import ch.iet_gibb.heatcalculatorfx.model.GeneralHeatstorage;
import ch.iet_gibb.heatcalculatorfx.model.Property;
import ch.iet_gibb.heatcalculatorfx.view.HeatstorageView_1;
import ch.iet_gibb.heatcalculatorfx.view.ViewInterface;
import javafx.event.ActionEvent;

import java.util.ArrayList;
import java.util.List;

/**
 * Controller class for the Heat Calculator FX application.
 * Manages the interaction between the models and the view.
 */
public class HeatCalculatorController implements javafx.event.EventHandler<ActionEvent> {

    // List of heat storage models
    protected List<GeneralHeatstorage> models;

    // Reference to the view interface
    protected ViewInterface view;

    // Index of the currently displayed heat storage
    protected int currentHeatstorage = 0;

    /**
     * Constructor for the HeatCalculatorController.
     *
     * @param models A list of GeneralHeatstorage objects representing the heat storage models.
     */
    public HeatCalculatorController(List<GeneralHeatstorage> models) {
        this.models = models;
    }

    /**
     * Handles action events, such as button clicks, to show the next heat storage.
     *
     * @param actionEvent The action event triggered by the user.
     */
    @Override
    public void handle(ActionEvent actionEvent) {
        showNextHeatstorage();
    }

    /**
     * Sets the view for the controller.
     *
     * @param view The view interface to be associated with the controller.
     */
    public void setView(ViewInterface view) {
        this.view = view;
    }

    /**
     * Starts the view by invoking its startView method.
     */
    public void startView() {
        view.startView();
    }

    /**
     * Cycles through the list of heat storages and updates the view to display the next one.
     * Resets to the first heat storage if the end of the list is reached.
     */
    public void showNextHeatstorage() {
        if (currentHeatstorage < models.size() - 1) {
            currentHeatstorage++;
        } else {
            currentHeatstorage = 0;
        }
        view.startView();
    }

    /**
     * Retrieves the properties of the currently displayed heat storage.
     *
     * @return A list of Property objects representing the current heat storage's properties.
     */
    public ArrayList<Property> getHeatstorage() {
        return models.get(currentHeatstorage).getProperties();
    }

    /**
     * Retrieves a string representation of the currently displayed heat storage.
     *
     * @return A string describing the current heat storage.
     */
    public String getHeatcalculator() {
        return models.get(currentHeatstorage).toString();
    }
}